@@ -26,7 +26,7 @@ def get_error_details():
 class Error(Exception):
     code = None
     display = None
-    status_code = 500
+    status_code = 400
     blocking = False
 
     def __init__(self, display=None, **data):
@@ -156,7 +156,7 @@ class MobileNumberRequired(Error):
 
 class SendCooldown(Error):
     code = "resend_cooldown"
-    display = _("Please wait before resending your verification")
+    display = _("Please wait at least {can_resend_in} seconds before resending your verification")
 
 
 class EmailNotSet(Error):
