@@ -7,12 +7,12 @@ from django.contrib import messages
 from django.views.generic import FormView, TemplateView
 from django.urls import reverse_lazy, reverse
 from django.http import HttpResponseRedirect
-import phonenumbers
-from .forms import *
-from .utils import *
 
+from . import errors, forms
+from .app_settings import conf
 from .client import TwoFAClient
-from .errors import *
+from .utils import get_setting, URL_PREFIX
+
 
 
 __all__ = [
@@ -24,7 +24,7 @@ __all__ = [
 logger = logging.getLogger("django_twilio_2fa")
 
 
-class Twilio2FAMixin(object):
+class Twilio2FAMixin:
     def setup(self, request, *args, **kwargs):
         super().setup(request, *args, **kwargs)
 
@@ -38,7 +38,7 @@ class Twilio2FAMixin(object):
     def dispatch(self, request, *args, **kwargs):
         try:
             return super().dispatch(request, *args, **kwargs)
-        except Error as e:
+        except errors.Error as e:
             error = e.get_json()
             del error["data"]  # Remove data for security
             error = json.dumps(error)
@@ -67,7 +67,7 @@ class Twilio2FAMixin(object):
 
 
 class Twilio2FARegistrationFormView(Twilio2FAMixin, FormView):
-    form_class = Twilio2FARegistrationForm
+    form_class = forms.Twilio2FARegistrationForm
     success_url = reverse_lazy("twilio_2fa:start")
     template_name = "twilio_2fa/register.html"
 
@@ -164,7 +164,7 @@ class Twilio2FAStartView(Twilio2FAMixin, TemplateView):
             )
 
         if not len(self.user_methods):
-            raise NoMethodAvailable()
+            raise errors.NoMethodAvailable()
 
         clear_session = request.GET.get("c")
 
@@ -172,30 +172,33 @@ class Twilio2FAStartView(Twilio2FAMixin, TemplateView):
             self.twofa_client.session.clear()
 
         if self.twofa_client.verification_expires_in() > 0:
-            # Verification hasn't expired
-            if self.twofa_client.can_resend_verification_in() <= 0:
-                # Resend verification
+            # Verification hasn't expired or been canceled, so this is a resend
+            try:
                 self.twofa_client.send_verification(
                     self.twofa_client.session["verification_method"]
                 )
                 messages.add_message(
                     request,
                     messages.SUCCESS,
-                    _("Verification has been resent")
+                    self.twofa_client.get_message("verification_resent")
                 )
-            else:
-                # Cooldown not met
+            except errors.SendCooldown as exc:
                 messages.add_message(
                     request,
                     messages.WARNING,
-                    _("Please wait before resending verification")
+                    exc.get_display()
+                )
+            except errors.Error as exc:
+                messages.add_message(
+                    request,
+                    messages.ERROR,
+                    exc.get_display()
                 )
 
             return HttpResponseRedirect(
                 self.success_url
             )
 
-
         if len(self.user_methods) == 1 and conf.send_immediately_on_single():
             # If only one option exists, we start the verification and send the user on
             self.twofa_client.send_verification(
@@ -218,7 +221,7 @@ class Twilio2FAStartView(Twilio2FAMixin, TemplateView):
 
 
 class Twilio2FAVerifyView(Twilio2FAMixin, FormView):
-    form_class = Twilio2FAVerifyForm
+    form_class = forms.Twilio2FAVerifyForm
     success_url = reverse_lazy("twilio_2fa:success")
     template_name = "twilio_2fa/verify.html"
 
